Struct SslSignatureAlgorithm

pub struct SslSignatureAlgorithm(/* private fields */);
A signature verification algorithm.

WARNING: The current implementation of From is unsound, as it’s possible to create an SslSignatureAlgorithm that is not defined by the impl. From will be deprecated in favor of TryFrom in the next major bump of the library.

Implementations